# Quickstart

To use jTWA for your own research, the `main.py` file located in the root directory of the repository may serve as a good starting point.

It is to be executed in conjunction with a configuration file `config.json` that is located in the same directory.
The configuration file is meant to be used to easily change things like system or simulation parameters, without adapting the code.

To run the example file that is provided, simply execute 

```
python main.py config.json
```

in the root directory with the previously installed virtual environment activated.